| Title: | Support Functions for (Reproducible) Descriptive Statistics |
|---|---|
| Description: | Contains functions to help with generating tables with descriptive statistics. In addition, the package can display results of statistical tests for group comparisons. A wide range of test procedures is supported, and user-defined test functions can be incorporated. |
| Authors: | Andreas Leha [aut], Fabian Kück [aut, cre] |
| Maintainer: | Fabian Kück <[email protected]> |
| License: | GPL-3 |
| Version: | 1.2 |
| Built: | 2026-06-01 08:48:31 UTC |
| Source: | https://github.com/cran/descsuppR |
Does not safeguard against "26:69".
as.tod(x) ## S3 method for class 'character' as.tod(x) ## S3 method for class 'circular' as.tod(x) is.tod(x) ## S3 method for class 'tod' as.double(x, ...) circular(x, ...) ## Default S3 method: circular( x, type = c("angles", "directions"), units = c("radians", "degrees", "hours"), template = c("none", "geographics", "clock12", "clock24"), modulo = c("asis", "2pi", "pi"), zero = 0, rotation = c("counter", "clock"), names = NULL, ... ) ## S3 method for class 'tod' circular(x, ...)as.tod(x) ## S3 method for class 'character' as.tod(x) ## S3 method for class 'circular' as.tod(x) is.tod(x) ## S3 method for class 'tod' as.double(x, ...) circular(x, ...) ## Default S3 method: circular( x, type = c("angles", "directions"), units = c("radians", "degrees", "hours"), template = c("none", "geographics", "clock12", "clock24"), modulo = c("asis", "2pi", "pi"), zero = 0, rotation = c("counter", "clock"), names = NULL, ... ) ## S3 method for class 'tod' circular(x, ...)
x |
An object to be converted to or represented as a circular object. |
... |
Additional arguments passed to methods or lower-level functions. |
type |
Character string indicating if data represent "angles" or "directions". |
units |
Character string; the measurement units for the input data ( |
template |
Character string specifying a specific template for circular data. |
modulo |
Character string indicating the modulo arithmetic to be used ( |
zero |
Numeric; direction assigned as zero (in the specified units). |
rotation |
Character string; direction of rotation for increasing values ( |
names |
Optional character vector of names for the object. |
x converted to/from 'tod'
Dr. Andreas Leha
times <- c("8:53", NA, "22:30") ## some conversions as.tod(times) as.numeric(as.tod(times)) is.tod(times) is.tod(as.tod(times))times <- c("8:53", NA, "22:30") ## some conversions as.tod(times) as.numeric(as.tod(times)) is.tod(times) is.tod(as.tod(times))
Calculate and Present Descriptive Values in Pritable
buildDescrTbl( df, tests, prmnames, prmunits, addFactorLevelsToNames = TRUE, excel_style = TRUE, groupby, addungrouped = FALSE, dopvals = FALSE, ignore_test_errors = FALSE, p.adjust.method = "holm", orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, report_tests = FALSE, report_testmessages = FALSE, pvals_formatting = TRUE, pvals_digits = 3, pvals_signiflev = 0.05, extraLevels = NULL, missingName = "missing", nonNAsName = "N", removeZeroNAs = TRUE, removeZeroExtraLevels = TRUE, includeNAs = FALSE, includeNonNAs = FALSE, printOrgAlignment = FALSE, useutf8 = "latex", verbose = 0, without_attrs = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE, percentages = "columnwise" )buildDescrTbl( df, tests, prmnames, prmunits, addFactorLevelsToNames = TRUE, excel_style = TRUE, groupby, addungrouped = FALSE, dopvals = FALSE, ignore_test_errors = FALSE, p.adjust.method = "holm", orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, report_tests = FALSE, report_testmessages = FALSE, pvals_formatting = TRUE, pvals_digits = 3, pvals_signiflev = 0.05, extraLevels = NULL, missingName = "missing", nonNAsName = "N", removeZeroNAs = TRUE, removeZeroExtraLevels = TRUE, includeNAs = FALSE, includeNonNAs = FALSE, printOrgAlignment = FALSE, useutf8 = "latex", verbose = 0, without_attrs = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE, percentages = "columnwise" )
df |
data.frame containing the variables of which to calc the descriptive values |
tests |
character vector or list of characters or list of functions or list of lists. In each case the i-th element gives the test to perform on the ith variable in the df (excluding stratification variables). The test can either be given as character (name of test function) or as function or as list where the first element is again either character or function and the following elemenst are *named* additional arguments to that test function. The individual function has to accept (at least) the arguments 'values' and 'grouping' which are vectors of equal length. For convenience, this package shipes with some example functions; have a look at those if you want to supply your own. These convenience functions include w.chisq.test w.cor.test, w.fisher.test, w.kruskal.test, w.wilcox.test. the whole list/vector is recycled if too short. |
prmnames |
names of the variables in df (if needed to be overwritten) |
prmunits |
units of the variables in df |
addFactorLevelsToNames |
logical. if |
excel_style |
logical. if TRUE remove subsequent duplicates from the |
groupby |
column of df. do more columns - one for each group. If the df$column is an ordered factor, the order will be respected in the resulting table |
addungrouped |
logical. if |
dopvals |
boolean. if TRUE an additional column containing the p-values comparing the two strata in |
ignore_test_errors |
logical. If |
p.adjust.method |
character. if not NULL include an
additional column with adjusted p values. see
|
orderedAsUnordered |
logical. treat ordered factors as unordered factors? |
factorlevellimit |
integer. for factors with more than
|
show.minmax |
logical. if TRUE show minimum and maximum for numeric variables. Defaults to |
show.IQR |
logical. if TRUE show 25% and 75% quantiles for numeric variables. Defaults to |
report_tests |
boolean. if TRUE one additional column in the result table will contain the test, that was performed to calculate the p value. Ignored if dopvals=FALSE |
report_testmessages |
boolean. if TRUE one additional column in the result table will contain any warnings that appeared while the test was performed. Ignored if dopvals=FALSE |
pvals_formatting |
boolean. If FALSE report numbers, else report formatted strings (via prettyPvalue) |
pvals_digits |
integer. Number of digits for p value formatting. Ignored when pvals_formatting==FALSE. Defaults to 2 |
pvals_signiflev |
double. The significance level for bold p value formatting. Ignored when pvals_formatting==FALSE. Defaults to 0.05 |
extraLevels |
named list of lists. Names have to be variable names. Elements have to have to be named list of this form: |
missingName |
character. name of missing values (default: |
nonNAsName |
character. name of not missing values (default: |
removeZeroNAs |
boolean. if TRUE, rows for missing values containing only 0s are removed from the result. |
removeZeroExtraLevels |
boolean. if TRUE, rows for ExtraLevels containing only 0s are removed from the result. |
includeNAs |
boolean. Include number of NAs in the output? Currently only one of either |
includeNonNAs |
boolean. Include number of not missing values (Non-NAs) in the output? Currently only one of either |
printOrgAlignment |
boolean. If TRUE, than a row like "<l> <r> <r>" will be included in the result df |
useutf8 |
character. one of c("latex", "utf8", "replace"). if 'latex' (the default) use \pm in the output; if 'replace' use +- in the output, if 'utf8' use the unicode character |
verbose |
numeric. level of verbosity (0 : silent) |
without_attrs |
logical. If |
sd_digits |
character. one of c("by_mean", "fixed"). If 'by_mean', the number of decimal places of the standard deviation is limited by the number of decimal places of the mean. |
descr_digits |
integer. Number of digits for formatting of descriptive values. Defaults to 2. |
significant_digits |
boolean. if TRUE, the number of significant digits of is given by descr_digits. Otherwise the number of decimal places is fixed. |
percentages |
character. one of c("columnwise", "rowwise"). If 'rowwise', percentages are computed by row. Defaults to "columnwise" |
Do a Table containing descriptiva values
formatted data.frame with descriptive values
Andreas Leha
ttt <- data.frame(data="training set", age=runif(100, 0, 100), sex=sample(c("m","f"), 100, replace=TRUE, prob=c(0.3, 0.7)), score=factor(sample(1:5, 100, replace=TRUE), ordered=TRUE, levels=1:5)) ttt2 <- data.frame(data="test set", age=runif(100, 0, 100), sex=sample(c("m","f"), 100, replace=TRUE, prob=c(0.5,0.5)), score=factor(sample(1:5, 100, replace=TRUE), ordered=TRUE, levels=1:5)) units <- c("years", "", "") buildDescrTbl(rbind(ttt, ttt2), prmunits=units, groupby="data", includeNAs=TRUE)ttt <- data.frame(data="training set", age=runif(100, 0, 100), sex=sample(c("m","f"), 100, replace=TRUE, prob=c(0.3, 0.7)), score=factor(sample(1:5, 100, replace=TRUE), ordered=TRUE, levels=1:5)) ttt2 <- data.frame(data="test set", age=runif(100, 0, 100), sex=sample(c("m","f"), 100, replace=TRUE, prob=c(0.5,0.5)), score=factor(sample(1:5, 100, replace=TRUE), ordered=TRUE, levels=1:5)) units <- c("years", "", "") buildDescrTbl(rbind(ttt, ttt2), prmunits=units, groupby="data", includeNAs=TRUE)
Internal wrapper around calc_descr_matrix
buildDescrTbl.intern( df, prmnames, prmunits, addFactorLevelsToNames = TRUE, extraLevels = NULL, includeNAs = FALSE, includeNonNAs = FALSE, orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE )buildDescrTbl.intern( df, prmnames, prmunits, addFactorLevelsToNames = TRUE, extraLevels = NULL, includeNAs = FALSE, includeNonNAs = FALSE, orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE )
df |
data.frame containing the variables of which to calc the descriptive values |
prmnames |
names of the variables in df (if needed to be overwritten) |
prmunits |
units of the variables in df |
addFactorLevelsToNames |
logical. if |
extraLevels |
named list of lists. Names have to be variable names. Elements have to have to be named list of this form: |
includeNAs |
boolean. Include number of NAs in the output? Currently only one of either |
includeNonNAs |
boolean. Include number of not missing values (Non-NAs) in the output? Currently only one of either |
orderedAsUnordered |
logical. treat ordered factors as unordered factors? |
factorlevellimit |
integer. for factors with more than
|
show.minmax |
logical. if TRUE show minimum and maximum for numeric variables. Defaults to |
show.IQR |
logical. if TRUE show 25% and 75% quantiles for numeric variables. Defaults to |
sd_digits |
character. one of c("by_mean", "fixed"). If 'by_mean', the number of decimal places of the standard deviation is limited by the number of decimal places of the mean. |
descr_digits |
integer. Number of digits for formatting of descriptive values. Defaults to 2. |
significant_digits |
boolean. if TRUE, the number of significant digits of is given by descr_digits. Otherwise the number of decimal places is fixed. |
matrix with descriptive values
Andreas Leha
Wrapper for single vectors
calc_descr_matrix( ttt, format = "long", extraLevels = NULL, includeNAs = FALSE, includeNonNAs = FALSE, orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE )calc_descr_matrix( ttt, format = "long", extraLevels = NULL, includeNAs = FALSE, includeNonNAs = FALSE, orderedAsUnordered = FALSE, factorlevellimit = 14, show.minmax = TRUE, show.IQR = FALSE, sd_digits = "by_mean", descr_digits = 2, significant_digits = TRUE )
ttt |
the data.frame |
format |
in c("long", "wide") |
extraLevels |
named list of lists. Names have to be variable names. Elements have to have to be named list of this form: |
includeNAs |
boolean. include number of NAs in the output? |
includeNonNAs |
boolean. include number of non-NAs in the output? |
orderedAsUnordered |
logical. treat ordered factors as unordered factors? |
factorlevellimit |
integer. for factors with more than
|
show.minmax |
logical. if TRUE show minimum and maximum for numeric variables. Defaults to |
show.IQR |
logical. if TRUE show 25% and 75% quantiles for numeric variables. Defaults to |
sd_digits |
character. one of c("by_mean", "fixed"). If 'by_mean', the number of decimal places of the standard deviation is limited by the number of decimal places of the mean. |
descr_digits |
integer. Number of digits for formatting of descriptive values. Defaults to 2. |
significant_digits |
boolean. if TRUE, the number of significant digits of is given by descr_digits. Otherwise the number of decimal places is fixed. |
calls the one dimensional functions
matrix containing the descriptive values
Andreas Leha
For each unique value in the specified column of a data frame, creates a "subtable" where that value is moved as a group heading (first row) and the column is blanked for the remaining rows. Optionally, can "move along" specified metadata columns, shifting their first element to the last row.
convertColumnHeading(df, col, movealong = NULL)convertColumnHeading(df, col, movealong = NULL)
df |
A data frame to be processed. |
col |
Character. Name of the column in |
movealong |
Optional character vector of column names. For each group, these columns are rotated, placing their first value after the last row. |
The function uses plyr::ddply to split the data frame by the levels of col. For each group,
- Moves the grouping value to a heading (top row)
- Adds an empty row for formatting
- Optionally rotates metadata columns specified in movealong
This can be useful for preparing tables for presentation or reporting.
A data frame formatted with expanded headings per group.
Andreas Leha
df <- data.frame(Group = c("A", "A", "B", "B"), Data = 1:4, Meta = c("x", "y", "z", "w")) convertColumnHeading(df, "Group") convertColumnHeading(df, "Group", movealong = "Meta")df <- data.frame(Group = c("A", "A", "B", "B"), Data = 1:4, Meta = c("x", "y", "z", "w")) convertColumnHeading(df, "Group") convertColumnHeading(df, "Group", movealong = "Meta")
build a description table for survival estimates
descrSurvEstimate( S, strata, stratorder, survname = "survival time", evaltimes = c(3, 5), evaltimeunits = "years", digits = 2, includeNAs = TRUE, includeNonNAs = TRUE, missingName = "missing", nonNAsName = "N", stratheader = TRUE, pval = FALSE, pvals_formatting = TRUE, pvals_digits = 2, pvals_signiflev = 0.05, hr = FALSE )descrSurvEstimate( S, strata, stratorder, survname = "survival time", evaltimes = c(3, 5), evaltimeunits = "years", digits = 2, includeNAs = TRUE, includeNonNAs = TRUE, missingName = "missing", nonNAsName = "N", stratheader = TRUE, pval = FALSE, pvals_formatting = TRUE, pvals_digits = 2, pvals_signiflev = 0.05, hr = FALSE )
S |
survival objects from |
strata |
a list of vectors containing strata. If the vectors are ordered factors the columns will be used in the given order. |
stratorder |
(list of) character vector for the order of the reported columns. Overrides any order of strata |
survname |
the name of the survival time, e.g. 'DFS' |
evaltimes |
numeric vector. for which times to calculate the survival estimate |
evaltimeunits |
the unit of the survival times (years, months, ...) |
digits |
round to |
includeNAs |
boolean. Include number of NAs in the output? |
includeNonNAs |
Logical; if |
missingName |
character. name of the rows with missing numbers. Defaults to "missing". |
nonNAsName |
Character string; the name to use as the column heading for the number of non-missing (non-NA) values. Default is |
stratheader |
boolean. print the stratheader? Turn off for inclusion into a bigger table |
pval |
boolean. if TRUE, the p value from a cox model is printed in a separate column |
pvals_formatting |
boolean. If FALSE report numbers, else report formatted strings (via prettyPvalue) |
pvals_digits |
integer. Number of digits for p value formatting. Ignored when pvals_formatting==FALSE. Defaults to 2 |
pvals_signiflev |
double. The significance level for bold p value formatting. Ignored when pvals_formatting==FALSE. Defaults to 0.05 |
hr |
boolean. if TRUE, the hazard ratio (with confidence interval) is printed as well. (only has an effect if pval==TRUE) |
calculate the survival estimates at the specified times and return a nicely formatted table
a character matrix
Andreas Leha
if (require("survival")) { S <- Surv(aml$time, aml$status) descrSurvEstimate(S, evaltimes=c(19, 24), evaltimeunits="months") }if (require("survival")) { S <- Surv(aml$time, aml$status) descrSurvEstimate(S, evaltimes=c(19, 24), evaltimeunits="months") }
Extract the hours/minutes Component of time-of-day
hours.tod(x) minutes.tod(x)hours.tod(x) minutes.tod(x)
x |
vector of class tod |
numeric vector of length length(x) with hours/minutes
Dr. Andreas Leha
times <- as.tod(c("8:53", NA, "22:30")) hours.tod(times) minutes.tod(times)times <- as.tod(c("8:53", NA, "22:30")) hours.tod(times) minutes.tod(times)
These shoud just do whatever the same function does for character vectors
## S3 method for class 'tod' length(x) ## S3 method for class 'tod' x[i, ...] ## S3 replacement method for class 'tod' x[i, ...] <- value ## S3 method for class 'tod' x[[i, ...]] ## S3 replacement method for class 'tod' x[[i, ...]] <- value ## S3 method for class 'tod' c(...)## S3 method for class 'tod' length(x) ## S3 method for class 'tod' x[i, ...] ## S3 replacement method for class 'tod' x[i, ...] <- value ## S3 method for class 'tod' x[[i, ...]] ## S3 replacement method for class 'tod' x[[i, ...]] <- value ## S3 method for class 'tod' c(...)
x |
vector of class |
i |
integer of indices |
... |
to match the generics' arguments |
value |
of type |
as expected
Dr. Andreas Leha
times <- c("8:53", NA, "22:30") times <- as.tod(times) length(times) times[1] times[1] <- "07:00" c(times, times)times <- c("8:53", NA, "22:30") times <- as.tod(times) length(times) times[1] times[1] <- "07:00" c(times, times)
Functions to calculate descriptve values for timo-of-day vectors.
The heavy lifting is done by the circular package.
## S3 method for class 'tod' mean(x, ...) sd(x, ...) ## Default S3 method: sd(x, na.rm = FALSE, ...) ## S3 method for class 'tod' sd(x, na.rm = FALSE, ...) ## S3 method for class 'tod' median(x, na.rm = FALSE, ...) ## S3 method for class 'tod' min(..., na.rm = FALSE) ## S3 method for class 'tod' max(..., na.rm = FALSE) ## S3 method for class 'tod' quantile(x, ...)## S3 method for class 'tod' mean(x, ...) sd(x, ...) ## Default S3 method: sd(x, na.rm = FALSE, ...) ## S3 method for class 'tod' sd(x, na.rm = FALSE, ...) ## S3 method for class 'tod' median(x, na.rm = FALSE, ...) ## S3 method for class 'tod' min(..., na.rm = FALSE) ## S3 method for class 'tod' max(..., na.rm = FALSE) ## S3 method for class 'tod' quantile(x, ...)
x |
vector of class |
... |
additional args passed on to base stats or circular stats functions |
na.rm |
often passed through to correponding functions in the circular packages. Otherwise logitcal. Defaults to |
These functions are meant to provide the least surprising descriptive values.
descriptive values as would be returned for non-circular numeric vectors
Dr. Andreas Leha
times <- as.tod(c("21:53", NA, "22:30", "23:10", "23:58", "00:15", "01:01")) mean(times) mean(times, na.rm = TRUE)times <- as.tod(c("21:53", NA, "22:30", "23:10", "23:58", "00:15", "01:01")) mean(times) mean(times, na.rm = TRUE)
X-years prediction
pred.survfit(Sfit, time)pred.survfit(Sfit, time)
Sfit |
a survfit object |
time |
the time to calculate the estimate |
Calculate the X-years estimate of a survfit
the estimate
Andreas Leha
Replace German Umlaute
replaceGermanUmlauts(txt)replaceGermanUmlauts(txt)
txt |
character. within this txt the German umlauts will be replaced |
character. version of txt with all 'Umlaute' and
'scharfes s' replaced.
Andreas Leha
replaceGermanUmlauts("gefräßig")replaceGermanUmlauts("gefräßig")
wrap this around 'correlation' tests to get output formatted for buildDescrTbl
testWrapper(testfun, values, grouping, ignore_test_errors = FALSE, ...)testWrapper(testfun, values, grouping, ignore_test_errors = FALSE, ...)
testfun |
character or function. Which function to call. |
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
ignore_test_errors |
logical. If |
... |
additional parameters. are passed on to the testfun |
This function is called by buildDescrTbl in order to generate the comparison p values. Basically it just calls the provided testfun. Main purpose is, that it collects warnings and returns them as well.
list. the results from testfun plus the element 'warnings' containing all warnings collected from the run of testfun. the results from testfun are assumed to be of type list and are additionally assumed to contain at least the elements 'p.value' and 'method'.
Andreas Leha
One-way ANOVA that unifies the api to other tests
w.anova.test(values, grouping, na.rm = TRUE, ...)w.anova.test(values, grouping, na.rm = TRUE, ...)
values |
vector. The values to compare (age, gene expression, ...) |
grouping |
vector ef the same length as |
na.rm |
logcical. if TRUE (default) the |
... |
additional parameters. are passed on to |
the value of anova augmented by 'p.value' and 'method'
Dr. Andreas Leha
chisq.test with unified interface
w.chisq.test(values, grouping, ...)w.chisq.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the chisq.test |
just a call to chisq.test that unifies the api to other tests
the value chisq.test
Andreas Leha
Wrapper for CochranArmitageTest which is
a test for trend in binomial proportions across the levels of a
single variable
w.CochraneArmitageTrend.test(values, grouping, ...)w.CochraneArmitageTrend.test(values, grouping, ...)
values |
vector. The values to compare. Will be passed to
|
grouping |
of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the
|
the value of CochranArmitageTest
Dr. Andreas Leha
cor.test with unified interface
w.cor.test(values, grouping, ...)w.cor.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the cor.test |
just a call to cor.test that unifies the api to other tests
the value cor.test
Andreas Leha
fisher.test with unified interface
w.fisher.test(values, grouping, ...)w.fisher.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the fisher.test |
just a call to fisher.test that unifies the api to other tests computes the exact p-value if possible and simulates the p-value otherwise
the value fisher.test
Andreas Leha
JonckheereTerpstraTest with unified interface
w.JonckheereTerpstraTest(values, grouping, ...)w.JonckheereTerpstraTest(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the JonckheereTerpstraTest |
just a call to JonckheereTerpstraTest that unifies the api to other tests
the value JonckheereTerpstraTest
Fabian Kück
kruskal.test with unified interface
w.kruskal.test(values, grouping, ...)w.kruskal.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the kruskal.test |
just a call to kruskal.test that unifies the api to other tests
the value kruskal.test
Andreas Leha
no test but unified interface
w.no.test(values, grouping, ...)w.no.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. unused |
just returns NA. Included as pass through for non-testable variables
NA
Andreas Leha
npar.t.test with unified interface
w.npar.t.test(values, grouping, ...)w.npar.t.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the npar.t.test |
just a call to npar.t.test that unifies the api to other tests computes the ordinary Brunner-Munzel test for group sizes > 9 and the studentized permutation test version otherwise
the value npar.t.test
Fabian Kück
npar.t.test with unified interface
w.npar.t.test.permu(values, grouping, ...)w.npar.t.test.permu(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the npar.t.test |
just a call to npar.t.test that unifies the api to other tests computes the the studentized permutation test version of the Brunner-Munzel test
the value npar.t.test
Fabian Kück
prop.trend.test with unified interface
w.prop.trend.test(values, grouping, ...)w.prop.trend.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the prop.trend.test |
just a call to prop.trend.test that unifies the api to other tests
the value prop.trend.test
Fabian Kück
rankFD with unified interface
w.rankFD.mid.ranks(values, grouping, ...)w.rankFD.mid.ranks(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the rankFD |
just a call to rankFD with effect="weighted" that unifies the api to other tests
the value rankFD
Fabian Kück
rankFD with unified interface
w.rankFD.pseudo.ranks(values, grouping, ...)w.rankFD.pseudo.ranks(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the rankFD |
just a call to rankFD that unifies the api to other tests
the value rankFD
Fabian Kück
just a call to t.test that unifies the api to other tests
w.t.test(values, grouping, ...)w.t.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the t.test |
the value of t.test
Andreas Leha
just a call to watson.williams.test that unifies the api to other tests
w.watson.williams.test(values, grouping, ...)w.watson.williams.test(values, grouping, ...)
values |
vector. The values to compare. Will be passed to |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the |
the value of watson.williams.test
Dr. Andreas Leha
wilcox.test with unified interface
w.wilcox.test(values, grouping, ...)w.wilcox.test(values, grouping, ...)
values |
vector. The values to compare (age, toxicity score, gene expression, ...) |
grouping |
vector of the same length as values. treated as factor giving the group membership |
... |
additional parameters. are passed on to the wilcox.test |
just a call to wilcox.test that unifies the api to other tests
the value wilcox.test
Andreas Leha